HostedGitInfo

Struct HostedGitInfo 

pub struct HostedGitInfo { /* private fields */ }
The parsed information from a git hosting URL.

Implementations

Source

impl HostedGitInfo

pub fn from_url(giturl: &str) -> Result<Self, ParseError>

Parses a URL string and returns a HostedGitInfo struct, if successful. If parsing fails, a ParseError will be returned.

pub fn provider(&self) -> Provider

The type of hosting provider. (GitHub, Gitlab, Bitbucket, …)

pub fn user(&self) -> Option<&str>

The name of the user or organization on the git host.

This is using an Option because some hosting providers allow projects that are not scoped to a particular user or organization.

Example: https://github.com/Turbo87/hosted-git-info-rs.gitTurbo87

pub fn auth(&self) -> Option<&str>

The authentication part of the URL, if it exists.

Format: <USER>[:<PASSWORD>]

Example: https://user:password@github.com/foo/bar.gituser:password

pub fn project(&self) -> &str

The name of the project on the git host.

Example: https://github.com/Turbo87/hosted-git-info-rs.githosted-git-info-rs

pub fn committish(&self) -> Option<&str>

The branch, tag, commit, … part of the URL, if it exists.

Example: https://github.com/Turbo87/hosted-git-info-rs.git#rust-is-awesomerust-is-awesome

pub fn default_representation(&self) -> DefaultRepresentation

The original URL type (shortcut, https, ssh, …).

Example: https://github.com/Turbo87/hosted-git-info-rs.gitHttps